#
# spec file for package mpc-qt
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           mpc-qt
Version:        17.11
Release:        2.2
Summary:        Media Player Classic Qute Theater
License:        GPL-2.0
Group:          Productivity/Multimedia/Video/Players
Url:            https://github.com/cmdrkotori/mpc-qt
Source0:        https://github.com/cmdrkotori/mpc-qt/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.changes
BuildRequires:  libqt5-linguist
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.4
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(mpv) >= 0.24
%if 0%{?suse_version} > 1320
BuildRequires:  gcc-c++
%else
%if 0%{?sle_version} == 120200
# Leap 42.2+ / SLE12SP2Backports
BuildRequires:  gcc6-c++
%else
BuildRequires:  gcc7-c++
%endif
%endif

%description
A clone of Media Player Classic reimplemented in Qt.

%prep
%setup -q
rm -rf mpv-dev
# fix builddate info
# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{SOURCE1} '+%%H:%%M:%%S')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{SOURCE1} '+%%b %%e %%Y')
sed -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" -i mainwindow.cpp
sed -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -i mainwindow.cpp

%build
export CC=gcc
export CXX=g++
test -x "$(type -p gcc-6)" && export CC=gcc-6
test -x "$(type -p g++-6)" && export CXX=g++-6
test -x "$(type -p gcc-7)" && export CC=gcc-7
test -x "$(type -p g++-7)" && export CXX=g++-7
qmake-qt5 \
  QMAKE_CFLAGS+="%{optflags}" QMAKE_CXXFLAGS+="%{optflags}" \
  QMAKE_CC="${CC}" QMAKE_CXX="${CXX}" PREFIX=%{_prefix} \
  mpc-qt.pro
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}/%{_bindir} \
         %{buildroot}/%{_datadir}/applications \
         %{buildroot}/%{_datadir}/pixmaps \
         %{buildroot}/%{_datadir}/%{name}/translations
install -m 0755 %{name} %{buildroot}/%{_bindir}
install -m 0644 images/icon/mpc-qt.svg %{buildroot}/%{_datadir}/pixmaps/%{name}.svg
install -m 0644 resources/translations/%{name}_*.qm -t %{buildroot}/%{_datadir}/%{name}/translations
install -m 0644 mpc-qt.desktop %{buildroot}/%{_datadir}/applications/Media\ Player\ Classic\ Qute\ Theater.desktop

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_datadir}/pixmaps/%{name}.svg
%{_datadir}/applications/*.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations/%{name}_*.qm
%doc LICENSE README.md

%changelog
* Wed Nov  1 2017 aloisio@gmx.com
- Update to version 17.11
  * Remember time of favorites
  * Remember correct config folder (#137)
  * Correct window frame calculation (#138)
  * Don't crash in a new ipc connection (#140)
- Dropped Qt-5.6-backport_setFlag.patch (merged upstream)
* Sun Oct  1 2017 aloisio@gmx.com
- Update to version 17.10
  * Implement favorites menu (use mouse for moving and renaming)
  * Implement mpris protocol (Linux only)
  * Improve .desktop file (Linux only)
  * Fix cli --size implementation (#89)
  * Fix save image filename extension (#127)
  * Use expected window placement on first run (#128)
- Use upstream .desktop file
- Fixed creation date and time
- Added Qt-5.6-backport_setFlag.patch
* Fri Sep  1 2017 aloisio@gmx.com
- Fixed locale path
* Fri Sep  1 2017 aloisio@gmx.com
- Update to version 17.09
  * Export MediaInfo to text file (#119)
  * USe correct mousewheel direction (#118)
  * Premangle the temporary image filename (#120)
  * Don't reset the play speed when pressing play (#117)
  * Honor --size argument (#89)
  * Add palette editor (some shades are drawn by the system on
    Windows)
  * Custom icons and basic themeing (#65)
  * Integration of argon's stats.lua (#104)
  * Populate audio device lists with mpv 0.26.0 (mentioned in #116)
  * Add right-click menu (#113)
  * Simplified resizing code (#114)
* Sun Aug 13 2017 aloisio@gmx.com
- Update to release 17.08
* Sun Jul  2 2017 aloisio@gmx.com
- Update to stable version 17.07
* Tue Jun  6 2017 olaf@aepfle.de
- Adjust usage of gccN-c++ for Leap42 and SLE12
* Wed May 31 2017 aloisio@gmx.com
- Change format for build date
- Add locale file
* Wed Mar  8 2017 aloisio@gmx.com
- Force gcc5 for Leap targets
* Wed Mar  8 2017 opensuse-packaging@opensuse.org
- Update to version 0~git20170308.548cd70:
  * Switch Unix/X11 to Linux behavior for consistency
  * mpvwidget: use undeprecated property names
  * readme: bump required mpv version to 0.24.0
  * remove outdated link
  * openfiledialog: add to project
  * [many]: implement open file dialog
  * readme: fix link to mpc-hc
  * settingswindow: implement video presets
  * settingswindow: remove reference to prescalers
  * qdrawnslider,qdrawnstatus: use QWidget as base class
* Fri Nov 18 2016 aloisio@gmx.com
- Initial package
